
// API for low-level SD card protocol implementation

#ifndef _BRD_SDIO_H
#define _BRD_SDIO_H

#include <stdbool.h>
#include <string.h>

#include <MDR32FxQI_port.h>
#include <MDR32FxQI_rst_clk.h>
#include <MDR32FxQI_sdio.h>

#include "sd_card_protocol.h"

// Use the "built-in" system timer handler if the project does not have its own.
// If you have your own handler, call SDIO_LL_DelayHandler() in it so that timeouts are counted.
#define USE_SYS_TIMER_HANDLER 0

#define SDIO_CR__PowerOn      SDIO_CR_SDE | SDIO_CR_CLKOE | SDIO_CR_CRC_EN_DATA
#define SDIO_CR__SendCMD      SDIO_CR_CRC_EN_CMD | SDIO_CR_SBITCMD | SDIO_CR_DIRCMD
#define SDIO_CR__ReadResp     SDIO_CR_CRC_EN_CMD | SDIO_CR_SBITCMD
#define SDIO_CR__SendCycles   SDIO_CR_DIRCMD

#define SDIO_CR__ReadBlock    SDIO_CR_CRC_EN_CMD | SDIO_CR_SBITDAT
#define SDIO_CR__WriteBlock   SDIO_CR_CRC_EN_CMD | SDIO_CR_SBITDAT | SDIO_CR_DIRDATA

#define SDIO_CR__ModeClear    (SDIO_CR_CRC_EN_CMD | SDIO_CR_SBITCMD | SDIO_CR_DIRCMD | SDIO_CR_SBITDAT | SDIO_CR_DIRDATA)

//--------------    SDIO Block Control -----------------

void SDIO_LL_Init(uint32_t periodSysTimer_1ms, SD_CARD_Timeouts_TypeDef* cfgTimeouts);
void SDIO_LL_DeInit(void);

//--------------  SD Card Control -----------------

SD_CARD_CMD_Result_TypeDef SDIO_LL_ExecCMD(uint32_t cmd, uint32_t arg, SD_CARD_ResponseLength_TypeDef respLength, uint32_t* response);

bool SDIO_LL_ReadBlock(uint8_t* buff, uint32_t blockSize);
bool SDIO_LL_WriteBlock(const uint8_t* buff);
bool SDIO_LL_SendClockCycles(uint32_t clockCycles);

bool SDIO_LL_GetPowerStatus(void);
void SDIO_LL_PowerOn(void);
void SDIO_LL_PowerOff(void);
void SDIO_LL_SetClockBRG(uint32_t clockBRG);
void SDIO_LL_StopTransfer(void);
bool SDIO_LL_IsCardInsert(void);

//  Timeouts
void     SDIO_LL_RunTimeout(uint32_t timeout_ms);
uint32_t SDIO_LL_GetTimeout(void);

// It is NECESSARILY to call the handler in an interrupt from a timer with a period of 1ms
void SDIO_LL_DelayHandler(void);

//  An example of starting a system timer through a function from brdSysTimer.c
//   SysTickStart(8000000UL/1000UL);                         // 1 ms with HCLK = 8MHz

//-------------   Debug Access-------------
SD_CARD_CMD_Result_TypeDef SDIO_LL_SendCMD(uint32_t cmd, uint32_t arg);

#endif //_BRD_SDIO_H
